from __future__ import annotations
from typing import List, Optional, TYPE_CHECKING

if TYPE_CHECKING:
	from entity import Entity

class Inventory:
	"""Handles inventory for an Entity"""
	_contents: List[Entity]

	def __init__(self, contents: List[Entity] = []):
		self._contents = contents

	def insert(self, entity: Entity) -> bool:
		if entity in self._contents:
			return False

		self._contents.append(entity)
		return True

	def access(self, index: int) -> Optional[Entity]:
		if index < 0 or  index >= len(self._contents):
			return None
		else:
			return self._contents[index]

	def withdraw(self, index: int) -> Optional[Entity]:
		if index < 0 or  index >= len(self._contents):
			return None
		else:
			return self._contents.pop(index)

	@property
	def contents(self) -> List[Entity]:
		return self._contents

#TODO: items need a weight, inventory needs a max capacity